@@ -2,7 +2,7 @@ package ExtUtils::ModuleMaker;
 use strict;
 use warnings;
 our (@ISA);
-our $VERSION = 0.57;
+our $VERSION = 0.58;
 use base qw(
     ExtUtils::ModuleMaker::Defaults
     ExtUtils::ModuleMaker::Initializers
@@ -452,8 +452,8 @@ Inside a Perl program:
 
 =head1 VERSION
 
-This document references version 0.57 of ExtUtils::ModuleMaker, released
-to CPAN on May 02 2018.
+This document references version 0.58 of ExtUtils::ModuleMaker, released
+to CPAN on May 05 2018.
 
 =head1 DESCRIPTION
 
@@ -693,19 +693,21 @@ F<Makefile.PL> gets messed up.  (Defaults to dummy copy.)
 
 =item * CPANID
 
-The CPANID of the author.  If this is omitted, then the line will not
-be added to the documentation.  (Defaults to dummy copy.)
+The CPANID of the author.  (Defaults to dummy copy. To suppress printing of
+this line entirely, set C<CPANID> to a Perl-false value such as an empty
+string.)
 
 =item * WEBSITE
 
-The personal or organizational website of the author.  If this is
-omitted, then the line will not be added to the documentation.
-(Defaults to dummy copy.)
+The personal or organizational website of the author.  (Defaults to dummy
+copy. To suppress printing of this line entirely, set C<CPANID> to a
+Perl-false value such as an empty string.)
 
 =item * ORGANIZATION
 
-Company or group owning the module.  If this is omitted, then the line
-will not be added to the documentation.  (Defaults to dummy copy.)
+Company or group owning the module.  (Defaults to dummy copy. To suppress
+printing of this line entirely, set C<CPANID> to a Perl-false value such as an
+empty string.)
 
 =back
 
