@@ -1,9 +1,7 @@
 package ExtUtils::ModuleMaker::Opts;
-#$Id$
 use strict;
 use warnings;
-use vars qw( $VERSION );
-$VERSION = 0.57;
+our $VERSION = 0.58;
 use Getopt::Std;
 $Getopt::Std::STANDARD_HELP_VERSION = 1;
 use Carp;
@@ -14,7 +12,11 @@ sub new {
     my $eumm_script   = shift;
 
     my %opts;
-    getopts( "bhqsCIPVcn:a:v:l:u:p:o:w:e:t:r:d:", \%opts );
+    getopts( "bhqsCIPVcn:a:v:l:u:p:o:w:e:r:d:", \%opts );
+    if ($opts{h}) {
+        print Usage($eumm_script, $eumm_package);
+        return;
+    }
 
     my $self = bless( {}, $class );
     $self->{NAME} = $class;
@@ -37,7 +39,7 @@ sub new {
         
         ( ( $opts{n} ) ? ( NAME                  => $opts{n} ) : () ),
         ( ( $opts{a} ) ? ( ABSTRACT              => $opts{a} ) : () ),
-        ( ( $opts{b} ) ? ( BUILD_SYSTEM          => $opts{b} ) : () ),
+        ( ( $opts{b} ) ? ( BUILD_SYSTEM          => 'Module::Build' ) : () ),
         ( ( $opts{v} ) ? ( VERSION               => $opts{v} ) : () ),
         ( ( $opts{l} ) ? ( LICENSE               => $opts{l} ) : () ),
         ( ( $opts{u} ) ? ( AUTHOR                => $opts{u} ) : () ),
@@ -65,16 +67,16 @@ sub get_standard_options {
 }
 
 sub Usage {
-    my ($script, $eumm_package, $eumm_version) = @_;
+    my ($script, $eumm_package) = @_;
     my $message = <<ENDOFUSAGE;
 modulemaker [-CIPVch] [-v version] [-n module_name] [-a abstract]
         [-u author_name] [-p author_CPAN_ID] [-o organization]
         [-w author_website] [-e author_e-mail]
-        [-l license_name] [-b build_system] [-s save_selections_as_defaults ]
+        [-l license_name] [-s save_selections_as_defaults ]
 
 Currently Supported Features
     -a   Specify (in quotes) an abstract for this extension
-    -b   Specify a build system for this extension
+    -b   Use Module::Build as build system for this extension
     -c   Flag for compact base directory name
     -C   Omit creating the Changes file, add HISTORY heading to stub POD
     -d   Call methods which override default methods from this module
@@ -94,8 +96,8 @@ Currently Supported Features
     -V   Flag for verbose messages during module creation
     -w   Specify author's web site
 
-$script version: $VERSION
-$eumm_package version: $eumm_version
+$script
+$eumm_package version: $VERSION
 ENDOFUSAGE
 
     return ($message);
